# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/shopping/location/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/shopping/location/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Shopping\\Location\\": "packages/shopping/location/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Shopping\Location\Providers\LocationServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Location'  => Shopping\Location\Facades\Location::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Shopping\\LocationTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Shopping\Location\Providers\LocationServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Shopping\Location\Providers\LocationServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Shopping\Location\Providers\LocationServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/location/{modulename}

**User**

    http://path-to-route-folder/user/location/{modulename}

**Public**

    http://path-to-route-folder/locations


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/location/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/location/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/location/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/location/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/location/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/location/{modulename}/{slug}
    METHOD: GET